@@ -18,6 +18,9 @@ import dbus as _dbus
 import dbus.service as _service
 
 from enum import Enum as _Enum
+from busutils import *
+
+import traceback
 
 #------------------------------------------------------------------------------
 
@@ -99,6 +102,16 @@ MODIFIER_NUMLOCK = ModifierType(7)
 MODIFIER_SHIFT = ModifierType(0)
 MODIFIER_SHIFTLOCK = ModifierType(1)
 
+def allModifiers():
+        """
+        Generates all possible keyboard modifiers for use with 
+        L{registry.Registry.registerKeystrokeListener}.
+        """
+        mask = 0
+        while mask <= (1 << MODIFIER_NUMLOCK):
+                yield mask
+                mask += 1
+
 #------------------------------------------------------------------------------
 
 class DeviceEvent(list):
@@ -251,8 +264,7 @@ class DeviceEventController(object):
 
         def __init__ (self, connection):
                 dec_object = connection.get_object(ATSPI_REGISTRY_NAME,
-                                                   ATSPI_DEVICE_EVENT_CONTROLLER_PATH,
-                                                   introspect=True)
+                                                   ATSPI_DEVICE_EVENT_CONTROLLER_PATH)
                 self._dec = _dbus.Interface(dec_object, ATSPI_DEVICE_EVENT_CONTROLLER_INTERFACE)
 
         def registerKeystrokeListener(self,
@@ -281,7 +293,7 @@ class DeviceEventController(object):
                 for the requested KeySet, ControllerEventMask, event types, and
                 EventListenerMode; otherwise returns False.
                 """
-                func = self._dec.get_dbus_method("registerKeystrokeListener")
+                func = self._dec.get_dbus_method("RegisterKeystrokeListener")
                 return func(event_listener,
                             _dbus.Array(keys, signature="(iisi)"),
                             event_mask,
@@ -304,7 +316,7 @@ class DeviceEventController(object):
                 @param : type
                 A list of KeyEventType
                 """
-                func = self._dec.get_dbus_method("deregisterKeystrokeListener")
+                func = self._dec.get_dbus_method("DeregisterKeystrokeListener")
                 return func(event_listener,
                             keys,
                             event_mask,
@@ -323,7 +335,7 @@ class DeviceEventController(object):
                 A list of EventType indicating which event types to listen for.
                 @return True if successful, False if not
                 """
-                func = self._dec.get_dbus_method("registerDeviceEventListener")
+                func = self._dec.get_dbus_method("RegisterDeviceEventListener")
                 return func(event_listener, event_types)
 
         def deregisterDeviceEventListener(self,
@@ -337,7 +349,7 @@ class DeviceEventController(object):
                 A List of EventType indicating which event types to stop listening
                 for.
                 """
-                func = self._dec.get_dbus_method("deregisterDeviceEventListener")
+                func = self._dec.get_dbus_method("DeregisterDeviceEventListener")
                 return func(event_listener, event_types)
 
         def notifyListenersSync(self, event):
@@ -354,7 +366,7 @@ class DeviceEventController(object):
                 e.g. the currently active application in the case of mouse or
                 keyboard events).
                 """
-                func = self._dec.get_dbus_method("notifyListenersSync")
+                func = self._dec.get_dbus_method("NotifyListenersSync")
                 return func(event)
 
         def notifyListenersAsync(self, event):
@@ -366,7 +378,7 @@ class DeviceEventController(object):
                 is potentially pre-emptible. notifyListenersSync should be used
                 instead.
                 """
-                func = self._dec.get_dbus_method("notifyListenersAsync")
+                func = self._dec.get_dbus_method("NotifyListenersAsync")
                 return func(event)
 
         def generateKeyboardEvent(self, keycode, keystring, type):
@@ -383,7 +395,7 @@ class DeviceEventController(object):
                 string (for instance from an internationalized or complex text
                 input method, or a composed character).
                 """
-                func = self._dec.get_dbus_method("generateKeyboardEvent")
+                func = self._dec.get_dbus_method("GenerateKeyboardEvent")
                 return func(keycode, keystring, type)
 
         def generateMouseEvent(self, x, y, name):
@@ -396,7 +408,7 @@ class DeviceEventController(object):
                 @param : name
                 A string indicating the type of mouse event, e.g. "button1up"
                 """
-                func = self._dec.get_dbus_method("generateMouseEvent")
+                func = self._dec.get_dbus_method("GenerateMouseEvent")
                 return func(x, y, name)
 
 #------------------------------------------------------------------------------
@@ -421,7 +433,7 @@ class KeyboardDeviceEventListener(_service.Object):
 
         def _get_unique_path (self):
                 KeyboardDeviceEventListener._next_listener_id += 1
-                return "/org/freedesktop/atspi/keyeventlistener/%d" % (KeyboardDeviceEventListener._next_listener_id,)
+                return "/org/a11y/atspi/keyeventlistener/%d" % (KeyboardDeviceEventListener._next_listener_id,)
 
         def __init__(self, registry, synchronous, preemptive, global_):
                 """
@@ -493,7 +505,7 @@ class KeyboardDeviceEventListener(_service.Object):
         @_service.method(dbus_interface=ATSPI_DEVICE_EVENT_LISTENER_INTERFACE,
                          in_signature="(uinnisb)",
                          out_signature="b")
-        def notifyEvent(self, ev):
+        def NotifyEvent(self, ev):
                 """
                 Notifies the L{Registry} that an event has occurred. Wraps the raw event 
                 object in our L{Event} class to support automatic ref and unref calls. An
@@ -510,7 +522,8 @@ class KeyboardDeviceEventListener(_service.Object):
                 try:
                         # wrap the device event
                         event = DeviceEvent(*ev)
-                        return self._registry._handleDeviceEvent(event, self)
+                        ret = self._registry._handleDeviceEvent(event, self)
+			return ret
                 except Exception, e:
                         import traceback
                         traceback.print_exc()
@@ -520,9 +533,9 @@ class KeyboardDeviceEventListener(_service.Object):
 
 class _DeviceEventRegister (object):
         
-        def __init__ (self, bus):
-                self.dev = DeviceEventController (bus)
-                self._bus = bus
+        def __init__ (self):
+                self._bus = SyncAccessibilityBus ()
+                self.dev = DeviceEventController (self._bus)
                 self.deviceClients = {}
 
         def registerKeystrokeListener(self,
@@ -544,7 +557,7 @@ class _DeviceEventRegister (object):
                         self.deviceClients[client] = ob
                 if mask is None:
                         # None means all modifier combinations
-                        mask = utils.allModifiers()
+                        mask = allModifiers()
                 # register for new keystrokes on the observer
                 ob.register(self.dev, key_set, mask, kind)
 
@@ -557,7 +570,7 @@ class _DeviceEventRegister (object):
                 ob = self.deviceClients[client]
                 if mask is None:
                         # None means all modifier combinations
-                        mask = utils.allModifiers()
+                        mask = allModifiers()
                 # register for new keystrokes on the observer
                 ob.unregister(self.dev, key_set, mask, kind)
 
